@@ -159,7 +159,7 @@ pub fn create_default_context(interactive: bool) -> Result<EvaluationContext, Bo
             whole_stream_command(Ansi),
             whole_stream_command(Char),
             // Column manipulation
-            whole_stream_command(MoveColumn),
+            whole_stream_command(Move),
             whole_stream_command(Reject),
             whole_stream_command(Select),
             whole_stream_command(Get),
@@ -180,6 +180,7 @@ pub fn create_default_context(interactive: bool) -> Result<EvaluationContext, Bo
             whole_stream_command(Nth),
             whole_stream_command(Drop),
             whole_stream_command(Format),
+            whole_stream_command(FileSize),
             whole_stream_command(Where),
             whole_stream_command(If),
             whole_stream_command(Compact),
@@ -198,6 +199,7 @@ pub fn create_default_context(interactive: bool) -> Result<EvaluationContext, Bo
             whole_stream_command(EachWindow),
             whole_stream_command(Empty),
             // Table manipulation
+            whole_stream_command(Flatten),
             whole_stream_command(Move),
             whole_stream_command(Merge),
             whole_stream_command(Shuffle),
@@ -221,6 +223,9 @@ pub fn create_default_context(interactive: bool) -> Result<EvaluationContext, Bo
             whole_stream_command(MathSummation),
             whole_stream_command(MathVariance),
             whole_stream_command(MathProduct),
+            whole_stream_command(MathRound),
+            whole_stream_command(MathFloor),
+            whole_stream_command(MathCeil),
             // File format output
             whole_stream_command(To),
             whole_stream_command(ToCSV),
@@ -273,6 +278,7 @@ pub fn create_default_context(interactive: bool) -> Result<EvaluationContext, Bo
             whole_stream_command(UrlPath),
             whole_stream_command(UrlHost),
             whole_stream_command(UrlQuery),
+            whole_stream_command(Seq),
         ]);
 
         #[cfg(feature = "clipboard-cli")]
@@ -388,13 +394,10 @@ pub async fn cli(mut context: EvaluationContext) -> Result<(), Box<dyn Error>> {
 
                 match nu_parser::lite_parse(&prompt_line, 0).map_err(ShellError::from) {
                     Ok(result) => {
-                        let mut prompt_block =
-                            nu_parser::classify_block(&result, context.registry());
+                        let prompt_block = nu_parser::classify_block(&result, context.registry());
 
                         let env = context.get_env();
 
-                        prompt_block.block.expand_it_usage();
-
                         match run_block(
                             &prompt_block.block,
                             &mut context,
@@ -857,8 +860,7 @@ pub async fn parse_and_eval(line: &str, ctx: &mut EvaluationContext) -> Result<S
     let lite_result = nu_parser::lite_parse(&line, 0)?;
 
     // TODO ensure the command whose examples we're testing is actually in the pipeline
-    let mut classified_block = nu_parser::classify_block(&lite_result, ctx.registry());
-    classified_block.block.expand_it_usage();
+    let classified_block = nu_parser::classify_block(&lite_result, ctx.registry());
 
     let input_stream = InputStream::empty();
     let env = ctx.get_env();
@@ -899,7 +901,7 @@ pub async fn process_line(
         debug!("=== Parsed ===");
         debug!("{:#?}", result);
 
-        let mut classified_block = nu_parser::classify_block(&result, ctx.registry());
+        let classified_block = nu_parser::classify_block(&result, ctx.registry());
 
         debug!("{:#?}", classified_block);
         //println!("{:#?}", pipeline);
@@ -1016,8 +1018,6 @@ pub async fn process_line(
             InputStream::empty()
         };
 
-        classified_block.block.expand_it_usage();
-
         trace!("{:#?}", classified_block);
         let env = ctx.get_env();
         match run_block(
