@@ -52,11 +52,12 @@ fn action(path: &Path) -> UntaggedValue {
 #[cfg(test)]
 mod tests {
     use super::PathType;
+    use super::ShellError;
 
     #[test]
-    fn examples_work_as_expected() {
+    fn examples_work_as_expected() -> Result<(), ShellError> {
         use crate::examples::test as test_examples;
 
-        test_examples(PathType {})
+        Ok(test_examples(PathType {})?)
     }
 }
