@@ -35,12 +35,13 @@ impl WholeStreamCommand for To {
 
 #[cfg(test)]
 mod tests {
+    use super::ShellError;
     use super::To;
 
     #[test]
-    fn examples_work_as_expected() {
+    fn examples_work_as_expected() -> Result<(), ShellError> {
         use crate::examples::test as test_examples;
 
-        test_examples(To {})
+        Ok(test_examples(To {})?)
     }
 }
