@@ -264,12 +264,13 @@ async fn to_json(
 
 #[cfg(test)]
 mod tests {
+    use super::ShellError;
     use super::ToJSON;
 
     #[test]
-    fn examples_work_as_expected() {
+    fn examples_work_as_expected() -> Result<(), ShellError> {
         use crate::examples::test as test_examples;
 
-        test_examples(ToJSON {})
+        Ok(test_examples(ToJSON {})?)
     }
 }
