@@ -126,9 +126,9 @@ impl Host for BasicHost {
     }
 
     fn width(&self) -> usize {
-        let (mut term_width, _) = term_size::dimensions().unwrap_or_else(|| (20, 20));
+        let (mut term_width, _) = term_size::dimensions().unwrap_or_else(|| (80, 20));
         term_width -= 1;
-        std::cmp::max(term_width, 20)
+        term_width
     }
 }
 
