@@ -7,17 +7,14 @@ use nu_source::{AnchorLocation, TaggedItem};
 
 use crate::prelude::*;
 
-use indexmap::indexmap;
 use num_bigint::BigInt;
 
-use indexmap::IndexMap;
-
 use crate::command_registry::CommandRegistry;
 use crate::commands::classified::block::run_block;
 use crate::commands::command::CommandArgs;
 use crate::commands::{
-    whole_stream_command, BuildString, Command, Each, Echo, Get, Keep, StrCollect,
-    WholeStreamCommand, Wrap,
+    whole_stream_command, BuildString, Command, Each, Echo, First, Get, Keep, Last, Nth,
+    StrCollect, WholeStreamCommand, Wrap,
 };
 use crate::evaluation_context::EvaluationContext;
 use crate::stream::{InputStream, OutputStream};
@@ -37,9 +34,12 @@ pub fn test_examples(cmd: Command) -> Result<(), ShellError> {
         // Minimal restricted commands to aid in testing
         whole_stream_command(Echo {}),
         whole_stream_command(BuildString {}),
+        whole_stream_command(First {}),
         whole_stream_command(Get {}),
         whole_stream_command(Keep {}),
         whole_stream_command(Each {}),
+        whole_stream_command(Last {}),
+        whole_stream_command(Nth {}),
         whole_stream_command(StrCollect),
         whole_stream_command(Wrap),
         cmd,
@@ -150,9 +150,12 @@ pub fn test_anchors(cmd: Command) -> Result<(), ShellError> {
         whole_stream_command(MockEcho {}),
         whole_stream_command(MockLs {}),
         whole_stream_command(BuildString {}),
+        whole_stream_command(First {}),
         whole_stream_command(Get {}),
         whole_stream_command(Keep {}),
         whole_stream_command(Each {}),
+        whole_stream_command(Last {}),
+        whole_stream_command(Nth {}),
         whole_stream_command(StrCollect),
         whole_stream_command(Wrap),
         cmd,
@@ -197,8 +200,7 @@ fn parse_line(line: &str, ctx: &mut EvaluationContext) -> Result<ClassifiedBlock
     let lite_result = nu_parser::lite_parse(&line, 0)?;
 
     // TODO ensure the command whose examples we're testing is actually in the pipeline
-    let mut classified_block = nu_parser::classify_block(&lite_result, ctx.registry());
-    classified_block.block.expand_it_usage();
+    let classified_block = nu_parser::classify_block(&lite_result, ctx.registry());
     Ok(classified_block)
 }
 
@@ -351,16 +353,33 @@ impl WholeStreamCommand for MockEcho {
                     Value {
                         value: UntaggedValue::Table(table),
                         ..
-                    } => futures::stream::iter(
-                        table
-                            .into_iter()
-                            .map(move |mut v| {
+                    } => {
+                        if table.len() == 1 && table[0].is_table() {
+                            let mut values: Vec<Value> =
+                                table[0].table_entries().map(Clone::clone).collect();
+
+                            for v in values.iter_mut() {
                                 v.tag = base_value.tag();
-                                v
-                            })
-                            .map(ReturnSuccess::value),
-                    )
-                    .to_output_stream(),
+                            }
+
+                            let subtable =
+                                vec![UntaggedValue::Table(values).into_value(base_value.tag())];
+
+                            futures::stream::iter(subtable.into_iter().map(ReturnSuccess::value))
+                                .to_output_stream()
+                        } else {
+                            futures::stream::iter(
+                                table
+                                    .into_iter()
+                                    .map(move |mut v| {
+                                        v.tag = base_value.tag();
+                                        v
+                                    })
+                                    .map(ReturnSuccess::value),
+                            )
+                            .to_output_stream()
+                        }
+                    }
                     _ => OutputStream::one(Ok(ReturnSuccess::Value(Value {
                         value: i.value.clone(),
                         tag: base_value.tag,
@@ -427,10 +446,6 @@ fn string(input: impl Into<String>) -> Value {
     UntaggedValue::string(input.into()).into_untagged_value()
 }
 
-fn row(entries: IndexMap<String, Value>) -> Value {
-    UntaggedValue::row(entries).into_untagged_value()
-}
-
 fn date(input: impl Into<String>) -> Value {
     let key = input.into().tagged_unknown();
     crate::value::Date::naive_from_str(key.borrow_tagged())
@@ -440,30 +455,30 @@ fn date(input: impl Into<String>) -> Value {
 
 fn file_listing() -> Vec<Value> {
     vec![
-        row(indexmap! {
-           "modified".to_string() =>   date("2019-07-23"),
+        row! {
                "name".to_string() => string("Andrés.txt"),
                "type".to_string() =>       string("File"),
            "chickens".to_string() =>              int(10),
-        }),
-        row(indexmap! {
-           "modified".to_string() =>   date("2019-07-23"),
+           "modified".to_string() =>   date("2019-07-23")
+        },
+        row! {
                "name".to_string() =>   string("Jonathan"),
                "type".to_string() =>        string("Dir"),
            "chickens".to_string() =>               int(5),
-        }),
-        row(indexmap! {
-           "modified".to_string() =>    date("2019-09-24"),
+           "modified".to_string() =>   date("2019-07-23")
+        },
+        row! {
                "name".to_string() =>  string("Andrés.txt"),
                "type".to_string() =>        string("File"),
            "chickens".to_string() =>               int(20),
-        }),
-        row(indexmap! {
-           "modified".to_string() =>    date("2019-09-24"),
+           "modified".to_string() =>    date("2019-09-24")
+        },
+        row! {
                "name".to_string() =>      string("Yehuda"),
                "type".to_string() =>         string("Dir"),
            "chickens".to_string() =>                int(4),
-        }),
+           "modified".to_string() =>    date("2019-09-24")
+        },
     ]
 }
 
