@@ -23,3 +23,15 @@ fn out_md_table() {
 
     assert_eq!(actual.out, "|name||-||jason|");
 }
+
+#[test]
+fn out_md_table_pretty() {
+    let actual = nu!(
+        cwd: ".", pipeline(
+        r#"
+            echo '{"name": "joseph"}' | from json | to md -p
+        "#
+    ));
+
+    assert_eq!(actual.out, "| name   || ------ || joseph |");
+}
